@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package Template::Overlay;
-$Template::Overlay::VERSION = '1.07';
+$Template::Overlay::VERSION = '1.08';
 # ABSTRACT: A powerful, and simple, library for resolving placeholders in templated files
 # PODNAME: Template::Resolver
 
@@ -94,7 +94,7 @@ sub _resolve {
     $logger->info( 'processing [', $template, '] -> [', $file, ']' );
 
     my $mode = stat($template)->mode() & 07777;    ## no critic
-    sysopen( my $handle, $file, O_CREAT | O_WRONLY, $mode )
+    sysopen( my $handle, $file, O_CREAT | O_TRUNC | O_WRONLY, $mode )
         || croak("open $file failed: $!");
     eval {
         print( $handle $self->{resolver}->resolve(
@@ -120,7 +120,7 @@ Template::Resolver - A powerful, and simple, library for resolving placeholders
 
 =head1 VERSION
 
-version 1.07
+version 1.08
 
 =head1 SYNOPSIS
 
